@@ -6,10 +6,9 @@ from matplotlib.gridspec import GridSpec
 import statsmodels
 
 
-StatsmodelsResults = statsmodels.discrete.discrete_model.BinaryResultsWrapper
 
 def statsmodels_fitting_result_dataframe(
-    res: StatsmodelsResults,
+    res,
     alpha: float = 0.05
     ) -> pd.DataFrame:
     """Create category and item columns from the statsmodels result.
@@ -135,7 +134,7 @@ def sort_category_item(df_: pd.DataFrame,
 
 def statsmodels_pretty_result_dataframe(
     data: pd.DataFrame,
-    res: StatsmodelsResults,
+    res,
     categorical: Dict[str, List[str]],
     order: List[str] = None,
     fml: str = ".2f",
